@@ -8,7 +8,8 @@ package IO::Async::Loop::Select;
 use strict;
 use warnings;
 
-our $VERSION = '0.21';
+our $VERSION = '0.30';
+use constant API_VERSION => '0.24';
 
 use base qw( IO::Async::Loop );
 
@@ -16,7 +17,7 @@ use Carp;
 
 =head1 NAME
 
-C<IO::Async::Loop::Select> - a Loop using the C<select()> syscall
+C<IO::Async::Loop::Select> - use C<IO::Async> with C<select(2)>
 
 =head1 SYNOPSIS
 
@@ -156,10 +157,7 @@ sub post_select
 
    my $iowatches = $self->{iowatches};
 
-   # Build a list of the callbacks to fire, then fire them afterwards.
-   # This avoids races and other bad effects if any of the callbacks happen
-   # to change any state.
-   my @ready;
+   my $count = 0;
 
    foreach my $fd ( keys %$iowatches ) {
       my $watch = $iowatches->{$fd};
@@ -167,21 +165,18 @@ sub post_select
       my $fileno = $watch->[0]->fileno;
 
       if( vec( $readvec, $fileno, 1 ) ) {
-         push @ready, $watch->[1] if defined $watch->[1];
+         $count++, $watch->[1]->() if defined $watch->[1];
       }
 
       if( vec( $writevec, $fileno, 1 ) ) {
-         push @ready, $watch->[2] if defined $watch->[2];
+         $count++, $watch->[2]->() if defined $watch->[2];
       }
    }
 
-   $_->() foreach @ready;
-
    # Since we have no way to know if the timeout occured, we'll have to
    # attempt to fire any waiting timeout events anyway
 
-   my $timequeue = $self->{timequeue};
-   $timequeue->fire if $timequeue;
+   $self->_manage_queues;
 }
 
 =head2 $count = $loop->loop_once( $timeout )
@@ -261,4 +256,4 @@ L<IO::Select> - OO interface to select system call
 
 =head1 AUTHOR
 
-Paul Evans E<lt>leonerd@leonerd.org.ukE<gt>
+Paul Evans <leonerd@leonerd.org.uk>
